@@ -34,6 +34,9 @@ namespace KWin
 {
 
 namespace ExtendedCursor {
+/**
+ * Extension of Qt::CursorShape with values not currently present there
+ **/
 enum Shape {
     SizeNorthWest = 0x100 + 0,
     SizeNorth = 0x100 + 1,
@@ -45,16 +48,13 @@ enum Shape {
     SizeSouthWest = 0x100 + 7
 };
 }
-/**
- * Extension of Qt::CursorShape with values not currently present there
- */
-
 
 /**
  * @brief Wrapper round Qt::CursorShape with extensions enums into a single entity
- */
+ **/
 class KWIN_EXPORT CursorShape {
 public:
+    CursorShape() = default;
     CursorShape(Qt::CursorShape qtShape) {
         m_shape = qtShape;
     }
@@ -69,7 +69,7 @@ public:
     }
     /**
      * @brief The name of a cursor shape in the theme.
-     */
+     **/
     QByteArray name() const;
 private:
     int m_shape = Qt::ArrowCursor;
@@ -103,37 +103,37 @@ public:
     /**
      * @brief Enables tracking changes of cursor images.
      *
-     * After enabling cursor change tracking the signal @link cursorChanged will be emitted
+     * After enabling cursor change tracking the signal cursorChanged will be emitted
      * whenever a change to the cursor image is recognized.
      *
-     * Use @link stopCursorTracking to no longer emit this signal. Note: the signal will be
+     * Use stopCursorTracking to no longer emit this signal. Note: the signal will be
      * emitted until each call of this method has been matched with a call to stopCursorTracking.
      *
      * This tracking is not about pointer position tracking.
      * @see stopCursorTracking
      * @see cursorChanged
-     */
+     **/
     void startCursorTracking();
     /**
      * @brief Disables tracking changes of cursor images.
      *
-     * Only call after using @link startCursorTracking.
+     * Only call after using startCursorTracking.
      *
      * @see startCursorTracking
-     */
+     **/
     void stopCursorTracking();
 
     /**
      * @brief The name of the currently used Cursor theme.
      *
      * @return const QString&
-     */
+     **/
     const QString &themeName() const;
     /**
      * @brief The size of the currently used Cursor theme.
      *
      * @return int
-     */
+     **/
     int themeSize() const;
     /**
      * @return list of alternative names for the cursor with @p name
@@ -144,7 +144,7 @@ public:
      * Returns the current cursor position. This method does an update of the mouse position if
      * needed. It's save to call it multiple times.
      *
-     * Implementing subclasses should prefer to use @link currentPos which is not performing a check
+     * Implementing subclasses should prefer to use currentPos which is not performing a check
      * for update.
      **/
     static QPoint pos();
@@ -156,7 +156,7 @@ public:
     static xcb_cursor_t x11Cursor(CursorShape shape);
     /**
      * Notice: if available always use the CursorShape variant to avoid cache duplicates for
-     * ambiguous cursor names in the non existing cursor name spcification
+     * ambiguous cursor names in the non existing cursor name specification
      **/
     static xcb_cursor_t x11Cursor(const QByteArray &name);
 
@@ -168,23 +168,23 @@ Q_SIGNALS:
     /**
      * @brief Signal emitted when the cursor image changes.
      *
-     * To enable these signals use @link startCursorTracking.
+     * To enable these signals use startCursorTracking.
      *
      * @see startCursorTracking
      * @see stopCursorTracking
-     */
+     **/
     void cursorChanged();
     void themeChanged();
 
 protected:
     /**
-     * Called from @link x11Cursor to actually retrieve the X11 cursor. Base implementation returns
+     * Called from x11Cursor to actually retrieve the X11 cursor. Base implementation returns
      * a null cursor, an implementing subclass should implement this method if it can provide X11
      * mouse cursors.
      **/
     virtual xcb_cursor_t getX11Cursor(CursorShape shape);
     /**
-     * Called from @link x11Cursor to actually retrieve the X11 cursor. Base implementation returns
+     * Called from x11Cursor to actually retrieve the X11 cursor. Base implementation returns
      * a null cursor, an implementing subclass should implement this method if it can provide X11
      * mouse cursors.
      **/
@@ -194,40 +194,40 @@ protected:
      **/
     virtual void doSetPos();
     /**
-     * Called from @link pos() to allow syncing the internal position with the underlying
+     * Called from @ref pos() to allow syncing the internal position with the underlying
      * system's cursor position.
      **/
     virtual void doGetPos();
     /**
-     * Called from @link startMousePolling when the mouse polling gets activated. Base implementation
+     * Called from startMousePolling when the mouse polling gets activated. Base implementation
      * does nothing, inheriting classes can overwrite to e.g. start a timer.
      **/
     virtual void doStartMousePolling();
     /**
-     * Called from @link stopMousePolling when the mouse polling gets deactivated. Base implementation
+     * Called from stopMousePolling when the mouse polling gets deactivated. Base implementation
      * does nothing, inheriting classes can overwrite to e.g. stop a timer.
      **/
     virtual void doStopMousePolling();
     /**
-     * Called from @link startCursorTracking when cursor image tracking gets activated. Inheriting class needs
+     * Called from startCursorTracking when cursor image tracking gets activated. Inheriting class needs
      * to overwrite to enable platform specific code for the tracking.
-     */
+     **/
     virtual void doStartCursorTracking();
     /**
-     * Called from @link stopCursorTracking when cursor image tracking gets deactivated. Inheriting class needs
+     * Called from stopCursorTracking when cursor image tracking gets deactivated. Inheriting class needs
      * to overwrite to disable platform specific code for the tracking.
-     */
+     **/
     virtual void doStopCursorTracking();
     bool isCursorTracking() const;
     /**
      * Provides the actual internal cursor position to inheriting classes. If an inheriting class needs
-     * access to the cursor position this method should be used instead of the static @link pos, as
+     * access to the cursor position this method should be used instead of the static @ref pos, as
      * the static method syncs with the underlying system's cursor.
      **/
     const QPoint &currentPos() const;
     /**
      * Updates the internal position to @p pos without warping the pointer as
-     * @link setPos does.
+     * setPos does.
      **/
     void updatePos(const QPoint &pos);
     void updatePos(int x, int y);
@@ -252,8 +252,7 @@ private:
  * @brief Implementation using the InputRedirection framework to get pointer positions.
  *
  * Does not support warping of cursor.
- *
- */
+ **/
 class InputRedirectionCursor : public Cursor
 {
     Q_OBJECT
@@ -300,4 +299,6 @@ inline bool Cursor::isCursorTracking() const
 
 }
 
+Q_DECLARE_METATYPE(KWin::CursorShape)
+
 #endif // KWIN_CURSOR_H
