@@ -31,9 +31,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <fcntl.h>
 #include <unistd.h>
 #include <config-kwin.h>
-#if HAVE_GBM
-#include <gbm.h>
-#endif
 
 namespace KWin
 {
@@ -56,14 +53,6 @@ VirtualBackend::VirtualBackend(QObject *parent)
 
 VirtualBackend::~VirtualBackend()
 {
-#if HAVE_GBM
-    if (m_gbmDevice) {
-        gbm_device_destroy(m_gbmDevice);
-    }
-#endif
-    if (m_drmFd != -1) {
-        close(m_drmFd);
-    }
 }
 
 void VirtualBackend::init()
@@ -124,9 +113,10 @@ Outputs VirtualBackend::enabledOutputs() const
     return m_enabledOutputs;
 }
 
-void VirtualBackend::setVirtualOutputs(int count, QVector<QRect> geometries)
+void VirtualBackend::setVirtualOutputs(int count, QVector<QRect> geometries, QVector<int> scales)
 {
     Q_ASSERT(geometries.size() == 0 || geometries.size() == count);
+    Q_ASSERT(scales.size() == 0 || scales.size() == count);
 
     bool countChanged = m_outputs.size() != count;
     qDeleteAll(m_outputs.begin(), m_outputs.end());
@@ -136,6 +126,9 @@ void VirtualBackend::setVirtualOutputs(int count, QVector<QRect> geometries)
     int sumWidth = 0;
     for (int i = 0; i < count; i++) {
         VirtualOutput *vo = new VirtualOutput(this);
+        if (scales.size()) {
+            vo->setScale(scales.at(i));
+        }
         if (geometries.size()) {
             vo->setGeometry(geometries.at(i));
         } else if (!vo->geometry().isValid()) {
